@@ -38,20 +38,22 @@ class PGG_diffusion:
         G,
         synergy,
         nb_simulation_step=1,
+        nb_seeder=1,
         cooperator_ratio=0.0,
         noise_var=0.0,
         maxlen_queue=200,
         ):
 
-        import random as rd
         import collections
         self._noise_var = noise_var
         self._G = G
         self._synergy = synergy
+        self._nb_node = len(G.nodes())
+        self._nb_seeder = nb_seeder
         self._nb_simulation_step = int(nb_simulation_step)
         self._nb_coop = collections.deque(maxlen=maxlen_queue)
         self._nb_def = collections.deque(maxlen=maxlen_queue)
-        self._infected_node = 1
+        self._infected_node = [RD.randint(0,self._nb_node) for x in xrange(self._nb_seeder)]
         self._simulation_time = 0
         self.reset_send_update()
         for nd in self._G.nodes_iter():
@@ -62,7 +64,7 @@ class PGG_diffusion:
 
             # Assign initial strategy
 
-            if rd.random() < cooperator_ratio:
+            if RD.random() < cooperator_ratio:
                 self._G.node[nd]['strategy'] = 'C'
             else:
                 self._G.node[nd]['strategy'] = 'D'
@@ -91,7 +93,7 @@ class PGG_diffusion:
 
         cost_i = 0
         for i in dealer_neighborhood:
-            if self._G.node[i]['strategy'] == 'C':
+            if self._G.node[i]['strategy'] == 'C' and self._G.node[i]['sent_update'] == 1:
                 Ki = self._G.degree(i)
                 cost_i += 1.0 / (Ki + 1)
         self._G.node[dealer]['payoff'] = self._synergy * cost_i \
@@ -127,12 +129,13 @@ class PGG_diffusion:
             for dealer in self._G.nodes_iter():
                 self.compute_payoffs(dealer)
             
-            self.set_time_stamp(self._infected_node, self._simulation_time)
+            for infected in self._infected_node:
+                self.set_time_stamp(infected, self._simulation_time)
             self.reset_send_update()
             self.diffusion_step()
-            for nd in self._G.nodes_iter():
-                if self._G.node[nd]['sent_update'] == 1:
-                    print 'node ', nd, ' sent a packet with time stamp = ', self._G.node[nd]['time_stamp'], ' at simulation time=', self._simulation_time
+            #for nd in self._G.nodes_iter():
+            #    if self._G.node[nd]['sent_update'] == 1:
+            #        print 'node ', nd, ' sent a packet with time stamp = ', self._G.node[nd]['time_stamp'], ' at simulation time=', self._simulation_time
             # Update the simuations variable
             self.store_cooperator_defector_counter()
             self.updateStrategy()
@@ -194,6 +197,10 @@ class PGG_diffusion:
             self._G.node[key]['time_stamp'] = val
             self._time_stamp = max(val, self._simulation_time)
 
+    def set_seeder(self, seeder):
+        self._infected_node = seeder
+
+
     def set_nodes_states(self, nodes_states):
         for (key, val) in nodes_states.iteritems():
             self._G.node[key]['state'] = val
@@ -241,6 +248,8 @@ class PGG_diffusion:
             sent_update[node] = self._G.node[node]['sent_update']
         return sent_update
 
+    def get_seeder(self):
+        return self._infected_node
     #
     # Reset
     #
